# CloWM Workflow Service

## Description

This is the Workflow service of the CloWM service.

## Environment Variables

### Mandatory / Recommended Variables

| Variable                               | Default            | Value                           | Description                                                                           |
|----------------------------------------|--------------------|---------------------------------|---------------------------------------------------------------------------------------|
| `PUBLIC_KEY_VALUE` / `PUBLIC_KEY_FILE` | randomly generated | Public Key / Path to Public Key | Public part of RSA Key in PEM format to verify JWTs                                   |
| `DB_HOST`                              | unset              | <db hostname / IP>              | IP or Hostname Address of DB                                                          |
| `DB_PORT`                              | 3306               | Number                          | Port of the database                                                                  |
| `DB_USER`                              | unset              | \<db username>                  | Username of the database user                                                         |
| `DB_PASSWORD`                          | unset              | \<db password>                  | Password of the database user                                                         |
| `DB_DATABASE`                          | unset              | \<db name>                      | Name of the database                                                                  |
| `OBJECT_GATEWAY_URI`                   | unset              | HTTP URL                        | HTTP URL of the Ceph Object Gateway                                                   |
| `BUCKET_CEPH_ACCESS_KEY`               | unset              | \<access key>                   | Ceph access key with admin privileges                                                 |
| `BUCKET_CEPH_SECRET_KEY`               | unset              | \<secret key>                   | Ceph secret key with admin privileges                                                 |
| `OPA_URI`                              | unset              | HTTP URL                        | HTTP URL of the OPA service                                                           |
| `SLURM_ENDPOINT`                       | unset              | HTTP URL                        | HTTP URL to communicate with the Slurm cluster                                        |
| `SLURM_TOKEN`                          | unset              | \<JWT>                          | JWT for communication with the Slurm REST API. Should belong to the user `SLURM_USER` |

### Optional Variables

| Variable                          | Default                 | Value                       | Description                                                                                                                      |
|-----------------------------------|-------------------------|-----------------------------|----------------------------------------------------------------------------------------------------------------------------------|
| `API_PREFIX`                      | `/api/workflow-service` | URL path                    | Prefix before every URL path                                                                                                     |
| `BACKEND_CORS_ORIGINS`            | `[]`                    | json formatted list of urls | List of valid CORS origins                                                                                                       |
| `SQLALCHEMY_VERBOSE_LOGGER`       | `False`                 | `<"True"&#x7c;"False">`     | Enables verbose SQL output.<br>Should be `false` in production                                                                   |
| `PARAMS_BUCKET`                   | `nxf-params`            | Bucket Name                 | Bucket where the nextflow configurations for each execution should be saved                                                      |
| `WORKFLOW_BUCKET`                 | `clowm-workflows`       | Bucket Name                 | Bucket where to save important workflow files                                                                                    |
| `ICON_BUCKET`                     | `clowm-icons`           | Bucket name                 | Bucket where to save workflow icons. Should be publicly available.                                                               |
| `SLURM_USER`                      | `slurm`                 | string                      | User on the slurm cluster who should run the job. Should be the user of the `SLURM_TOKEN`                                        |
| `PARAMS_BUCKET_MOUNT_PATH`        | `/mnt/params-bucket`    | Path on slurm cluster       | Folder where the S3 bucket `PARAMS_BUCKET` will be mounted on the slurm cluster                                                  |
| `NX_CONFIG`                       | unset                   | Path on slurm cluster       | Configuration file on the slurm cluster that is the same for every nextflow run                                                  |
| `NX_BIN`                          | `nextflow`              | Path on slurm cluster       | Path to the nextflow executable. Default it is in the `PATH`                                                                     |
| `SLURM_WORKING_DIRECTORY`         | `/tmp`                  | Path on slurm cluster       | Working directory for the slurm job with the nextflow command                                                                    |
| `ACTIVE_WORKFLOW_EXECUTION_LIMIT` | `3`                     | Integer                     | Limit of active workflow execution a user is allowed to have. `-1` means infinite.                                               |
| `DEV_SYSTEM`                      | `False`                 | `<"True"&#x7c;"False">`     | Activates an endpoint that allows execution of an workflow from an arbitrary Git Repository.<br>HAS TO BE `False` in PRODUCTION! |
| `OPA_POLICY_PATH`                 | `/clowm/authz/allow`    | URL path                    | Path to the OPA Policy for Authorization                                                                                         |
| `SLURM_JOB_STATUS_CHECK_INTERVAL` | 30                      | integer (seconds)           | Interval for checking the slurm jobs status after starting a workflow execution                                                  |
| `OTLP_GRPC_ENDPOINT`              | unset                   | <hostname / IP>             | OTLP compatible endpoint to send traces via gRPC, e.g. Jaeger                                                                    |


### Nextflow Variables

All [Nextflow environment variables](https://www.nextflow.io/docs/latest/config.html#environment-variables) with the
prefix `NXF_` are also support when submitting a job to the slurm cluster, e.g. pinning the Nextflow version

```
NXF_VER=23.04.0
```
