from uuid import UUID

from pydantic import BaseModel, ConfigDict, Field


class _BaseWorkflowMode(BaseModel):
    model_config = ConfigDict(from_attributes=True)
    schema_path: str = Field(
        ..., description="Path to the alternative parameter schema", examples=["modes/schema1.json"]
    )
    entrypoint: str = Field(
        ...,
        description="Name of the process the workflow should start with. Argument to the parameter '-entry'",
        examples=["example"],
    )
    name: str = Field(..., description="Name of the workflow mode", examples=["Example Name"])


class WorkflowModeIn(_BaseWorkflowMode):
    pass


class WorkflowModeOut(_BaseWorkflowMode):
    mode_id: UUID = Field(..., description="ID of the workflow mode", examples=["0cc78936-381b-4bdd-999d-736c40591078"])
